import { PubSub } from '../pub-sub';
import { VariableSizeList, FixedSizeList } from 'react-window';
type ListEventPayload = {
    focusListItem: {
        label: string;
        index: number | null;
    };
    selectListItem: {
        label: string;
        index: number;
        blur: boolean;
    };
    listItemMounted: {
        label: string;
        index: number;
    };
};
/**
 * A singleton event bus for accessible lists.
 */
export declare class AccessibleListPubSubSingleton {
    private static instance;
    static getInstance(): PubSub<keyof ListEventPayload, ListEventPayload>;
    static reset(): void;
}
export type TUseKeyboardListControllerOptions<T extends HTMLElement> = Partial<{
    /**
     * Optionally provide an existing ref to use instead of creating a new one.
     */
    ref: React.RefObject<T>;
    /**
     * The number of items in the list. If specified, the active item will be wrapped
     * around to the beginning of the list when the end is reached.
     */
    itemCount: number;
    /**
     * Whether to blur the controller when an item is selected.
     *
     * @default true
     */
    blurOnItemSelect: boolean;
    /**
     * Whether to reset the active item index when the list is blurred.
     *
     * @default false
     */
    resetActiveItemOnBlur: boolean;
    /**
     * Whether the list is controlled with up/down keys or left/right keys.
     *
     * @default 'vertical'
     */
    direction: 'vertical' | 'horizontal' | 'both';
}>;
/**
 * Used to create an accessible list. Call this in an input or other component that
 * should serve as the controller for a list. When it is focused and arrow keys are
 * pressed, elements using {@link useKeyboardListItem} will become active in sequence.
 * If the list is virtualized, use {@link useKeyboardVirtualList} to scroll to the
 * active item.
 */
export declare const useKeyboardListController: <T extends HTMLElement>(label: string, options?: TUseKeyboardListControllerOptions<T>) => {
    ref: import("react").RefObject<T>;
};
/**
 * Used to create an accessible list item. Call this in a list item component that
 * should get activated by keyboard navigation on a {@link useKeyboardListController}
 * component. If the list is virtualized, use {@link useKeyboardVirtualList} to
 * scroll to the active item.
 */
export declare const useKeyboardListItem: <T extends HTMLElement>(label: string, index: number, onSelect: () => void) => {
    isActive: boolean;
    ref: import("react").MutableRefObject<T | null>;
};
/**
 * Used to create a virtualized accessible list. Call this in a virtualized list
 * component that should scroll to an active {@link useKeyboardListItem} component
 * on a {@link useKeyboardListController} component.
 */
export declare const useKeyboardVirtualList: <T extends VariableSizeList | FixedSizeList>(label: string, options?: Partial<{
    ref: React.RefObject<T>;
}>) => {
    ref: import("react").RefObject<T>;
};
export {};
