import { TThemeOverride } from 'lib/types/theme';
import type { PostHog } from 'posthog-js';
import { ParsedMVF } from '@mappedin/mvf';
import type RootStore from '../../stores/root-store';
export type TStartViewerCommonOptions = {
    /**
     * Element to mount the viewer into.
     */
    root?: HTMLElement;
    /**
     * An option name to specify which view is being rendered. Will show up in parantheses
     * next to the map name.
     */
    subtitle?: string;
    /**
     * Option to specify the part of the URL that should be considered a prefix for all routes.
     * Defaults to `map`.
     */
    baseUrl?: string;
    /**
     * Override the default theme to a premade variant or a custom theme.
     */
    themeOverride?: TThemeOverride;
    /**
     * Option to override the behaviour when the share button is clicked. Return a truthy value
     * to play the success animation on the share button when clicked. Return a falsy value to
     * prevent the default animation.
     */
    overrideShareButtonHandler?: () => boolean | void;
    /**
     * Optional callback that gets executed when the RootStore initializes. Useful when trying
     * to control the app state from outside.
     */
    onRootStore?: (rootStore: RootStore) => void;
    /**
     * Option to disable analytics events from being sent. Will not disable the user from being
     * identified because feature flags still need to be pulled.
     */
    disableAnalytics?: boolean;
    /**
     * Optional key to override the default outdoor maps key.
     */
    outdoorMapsKey?: string;
    /**
     * Option to specify whether the app is being loaded as a preview.
     */
    isMakerPreview?: boolean;
    /**
     * Option to specify if the app should disable navigation support.
     */
    directionsUnavailable?: boolean;
    /**
     * Option to specify the map ID. If undefined, the map ID will be pulled from the URL.
     */
    mapId?: string;
    /**
     * Option to specify the config ID. If undefined, the config ID will be pulled from the URL.
     */
    configId?: string;
    /**
     * Option to hide the current app state from being shown in the URL.
     */
    hideRouterState?: boolean;
    /**
     * Option to hide the map ID from being shown in the URL.
     */
    hideMapIdInUrl?: boolean;
};
export type TStartViewerOptions = {
    /**
     * Public data URL to fetch an MVF from without auth. Should be configured to either the
     * production or staging MVF Azure function. This option will be ignored if `authUrl` is
     * provided; use `authDataUrl` instead to change where a private MVF is fetched from.
     */
    dataUrl?: string;
    /**
     * Optional API endpoint to try and fetch a token from. Used to load private data that is
     * secured behind a VPN.
     */
    authUrl?: string;
    /**
     * Private data URL from which to fetch an MVF with auth. This option will be ignored if
     * `authUrl` is not provided; use `authUrl` instead to change where a public MVF is fetched
     * from. Defaults to `https://app.mappedin.com`.
     */
    authDataUrl?: string;
} & TStartViewerCommonOptions;
export type MaybePromise<T> = T | Promise<T>;
export type MaybeFunction<T> = T | (() => T);
export type TStartViewerWithLocalDataOptions = {
    /**
     * A parsed MVF that represents some venue data. This can also be a Promise
     * which resolves to a parsed MVF, or a function that returns either of the
     * above.
     */
    data: MaybeFunction<MaybePromise<ParsedMVF | Record<string, unknown>>>;
    /**
     * Should be `mvf`. `json` is no longer supported and the option only exists for backwards
     * compatibility.
     */
    format?: 'mvf' | 'json';
    /**
     * Optional PostHog instance to use for analytics instead of the default instance created by
     * the viewer.
     */
    posthog?: PostHog;
} & TStartViewerCommonOptions;
