import UIStore from '../ui-store';
import MapStore from '../map-store';
import { E_DEPARTURE_MODE } from '../../lib/types/directions';
import { E_APP_STATE } from '../../lib/types/state';
import RouterStore from '../router-store';
import { TStartViewerOptions, TStartViewerWithLocalDataOptions } from '../../lib/types/options';
import FeatureFlagStore from '../feature-flag-store';
import { MapData, Place, Floor, Coordinate, Geometry, Area, LocationCategory, LocationProfile, FloorStack } from '../../lib/sdk';
import { processPlaces } from '../../lib/utils/process-places';
import SearchStore from '../search-store';
import { Feature, ParsedMVF, Point, SpaceProperties, Geometry as MVFGeometry } from '@mappedin/mvf';
import AnalyticsStore from '../analytics-store';
import { TTheme } from '../../lib/types/theme';
import { YOU_ARE_HERE_ROUTER_PARAM } from '../../lib/utils/url-utils';
import MessageStore from '../message-store';
export declare const RootStoreContext: import("react").Context<RootStore>;
declare class RootStore {
    private reactionDisposers;
    /**
     * This should not be exposed outside the root store. Root store observables, derived from the router
     * should be the source of truth for the rest of the application.
     */
    private routerStore;
    /**
     * We want to cache coordinates when we deserialize them, so we don't create new coordinate instances and
     * trigger unnecessary mobX reactions. We cache the last 10 coordinates only to avoid memory issues. We
     * shouldn't ever need to cache more than 10 coordinates at once, but if we do, we'll need to increase
     * {@link CACHED_COORDINATES_LENGTH}.
     */
    private cachedCoordinates;
    /**
     * We will gradually build up a dictionary of places by containing area ID. We'll query the rbushes
     * only whenever we haven't cached an area ID yet.
     */
    private placesByContainingAreaId;
    /**
     * The parsed MVF data for the map. This should only be undefined if some processing or loading issue
     * occurs.
     */
    readonly mvf: ParsedMVF;
    readonly data: MapData;
    readonly mapId: string | undefined;
    readonly configId: string | undefined;
    configName: string | undefined;
    readonly startupOptions: TStartViewerOptions | TStartViewerWithLocalDataOptions;
    featureFlagStore: FeatureFlagStore;
    uiStore: UIStore;
    mapStore: MapStore;
    searchStore: SearchStore;
    analyticsStore: AnalyticsStore;
    messageStore: MessageStore;
    departureMode: E_DEPARTURE_MODE;
    isAppMobile: boolean;
    isAppMini: boolean;
    /**
     * MVF dictionaries. These should not be exposed outside the root store. The rest of the app should
     * know as little about MVF as possible.
     */
    private readonly spacesById;
    private readonly obstructionsById;
    private readonly annotationsById;
    private readonly entrancesById;
    private readonly floorIdByFeatureId;
    private readonly areasById;
    private readonly connectionSpaceIdsByLatLonFloor;
    private readonly connectionSpaceIdsByLatLon;
    private readonly connectionSpaceIdsByRelatedConnectionId;
    /**
     * SDK data dictionaries.
     */
    readonly places: Exclude<Place, Coordinate>[];
    readonly placesById: Record<string, Exclude<Place, Coordinate>>;
    readonly placesByName: Record<string, Exclude<Place, Coordinate>[]>;
    readonly placesByNameNormalized: Record<string, Exclude<Place, Coordinate>[]>;
    readonly placesByFloorId: Record<string, Exclude<Place, Coordinate>[]>;
    readonly areasByFloorId: ReturnType<typeof processPlaces>['areasByFloorId'];
    readonly placeNamesByCategory: Record<string, string[]>;
    readonly placesWithMetadata: Exclude<Place, Coordinate>[];
    readonly geometries: Geometry[];
    readonly geometriesById: Record<string, Geometry>;
    readonly sortedPlaceNames: string[];
    readonly floorsByNameNormalized: Record<string, Floor>;
    readonly categoriesByNameNormalized: Record<string, LocationCategory>;
    readonly rbushByFloorId: ReturnType<typeof processPlaces>['rbushByFloorId'];
    constructor({ router, featureFlagStore, data, startupOptions, mvf, mapId, configId, configName, isMobile, isMini, theme, }: {
        router: RouterStore;
        featureFlagStore: FeatureFlagStore;
        data: MapData;
        startupOptions: TStartViewerOptions | TStartViewerWithLocalDataOptions;
        mvf: ParsedMVF;
        mapId?: string;
        configId?: string;
        configName?: string;
        isMobile: boolean;
        isMini: boolean;
        theme: TTheme;
    });
    /**
     * Compute what the new departure mode should be based on the current URL parameters. This can be
     * used to determine a departure mode before the `syncDeparture` reaction runs, which will clear
     * out departure places that do not match the current departure mode.
     */
    private inferDepartureMode;
    private checkForEmbeddedMode;
    private syncState;
    private syncCurrentFloor;
    private syncDeparture;
    private getMVFFeatureById;
    private isFloorEmpty;
    get title(): string;
    get timeZone(): string;
    get isMakerPreview(): boolean;
    get directionsUnavailable(): boolean;
    get isAppEmbedded(): boolean;
    /**
     * A campus is a map with multiple buildings (i.e. multiple floor stacks).
     */
    get isCampus(): boolean;
    get isKioskModeEnabled(): boolean;
    get isAccessible(): boolean;
    get isSafetyModeEnabled(): boolean;
    get isOutdoorsVisible(): boolean;
    /**
     * The initial pitch from the router params. To get the initial pitch with defaults from the theme,
     * use {@link UIStore.theme.map.initialPitch}.
     */
    get initialPitch(): number | undefined;
    /**
     * The initial bearing from the router params or MVF. To get the initial bearing with defaults from
     * the theme, use {@link UIStore.theme.map.initialBearing}.
     */
    get initialBearing(): number | undefined;
    get exteriorDoors(): {
        "__#15@#private": any;
        readonly __type: "door";
        readonly floor: Floor;
        readonly center: Coordinate;
        readonly isExterior: boolean;
        readonly geoJSON: {
            properties: null;
            type: import("@mappedin/mvf").FeatureType;
            geometry: import("@mappedin/mvf").LineString;
        };
        readonly focusTarget: Coordinate;
        readonly anchorTarget: Coordinate;
        toJSON(): {
            id: string;
            name: string;
            floor: string;
            center: {
                latitude: number;
                longitude: number;
                floor: string | undefined;
                verticalOffset: number;
            };
        };
        destroy(): void;
        "__#57@#private": any;
        readonly externalId: string;
        readonly name: string;
        readonly description: string;
        readonly images: {
            "__#23@#private": any;
            readonly url: string | undefined;
            readonly name: string | undefined;
            readonly altText: string | undefined;
            toJSON(): {
                id: string;
                url: string | undefined;
                name: string | undefined;
            };
            destroy(): void;
            readonly id: string;
        }[];
        readonly links: {
            "__#22@#private": any;
            readonly url: string;
            readonly name: string | undefined;
            toJSON(): {
                id: string;
                url: string;
                name: string | undefined;
            };
            destroy(): void;
            readonly id: string;
        }[];
        readonly locationProfiles: LocationProfile[];
        "__#58@#private": any;
        readonly id: string;
        readonly geoJSONBoundingBox: {};
    }[];
    get nonEmptyFloors(): Floor[];
    get nonEmptyFloorStacks(): FloorStack[];
    get currentFloorStack(): FloorStack | undefined;
    get outdoorFloor(): Floor | undefined;
    get sortedFloorsByFloorStack(): Map<FloorStack, Floor[]>;
    get floorClosestToGroundLevel(): Floor;
    get selectedPlaces(): Place[] | undefined;
    get selectedCategory(): LocationCategory | undefined;
    get selectedMVFFeatures(): Feature<MVFGeometry, {
        id: string;
    }>[] | undefined;
    get similarPlaces(): Place[] | undefined;
    get departures(): Place[] | undefined;
    get placeIdsWithImageLabels(): Set<string>;
    get youAreHere(): Coordinate | undefined;
    get defaultFloor(): Floor;
    get currentFloor(): Floor | undefined;
    get state(): E_APP_STATE;
    /**
     * Get places that are similar to a set of selected places.
     *
     * Note: Location profiles are not considered similar to other places. Instead, places
     * with the same location profile are considered similar to each other.
     */
    getSimilarPlaces(places: Place[]): Place[];
    /**
     * Try and find an array of {@link Place} objects by ID, name, or serialized coordinate.
     */
    resolvePlaces(query: string): Place[] | undefined;
    /**
     * Try and find a {@link Floor} by ID or name.
     */
    resolveFloor(query: string): Floor | undefined;
    /**
     * Try and find a {@link LocationCategory} by ID or name.
     */
    resolveCategory(query: string): LocationCategory | undefined;
    updateConfigName(configName: string): void;
    serializeCoordinate(coordinate: Coordinate): string;
    deserializeCoordinate(serializedCoordinate: string, options?: Partial<{
        fallbackFloorId: string;
    }>): Coordinate | undefined;
    setYouAreHere(coordinate: Coordinate | undefined): void;
    setState(state: E_APP_STATE): void;
    setSelectedPlaces(places: Place[] | undefined | typeof YOU_ARE_HERE_ROUTER_PARAM): void;
    /**
     * Only use this from within the editor preview.
     */
    setSelectedPlacesByMVFIds(ids: string[]): void;
    /**
     * Update the current departure places. By default, this will clear out departures that do not match
     * the current departure mode. Alternatively, you can pass in `updateDepartureMode: true` to force the
     * departure mode to be updated based on the new departures.
     */
    setDepartures(departures: Place[] | undefined | typeof YOU_ARE_HERE_ROUTER_PARAM, options?: Partial<{
        updateDepartureMode: boolean;
    }>): void;
    setCurrentFloor(floor: Floor | undefined): void;
    setDepartureMode(mode: E_DEPARTURE_MODE): void;
    setSelectedCategory(category: LocationCategory | undefined): void;
    setIsAppMobile(isMobile: boolean): void;
    setIsAppMini(isMini: boolean): void;
    setIsAccessible(isAccessible: boolean): void;
    setIsSafetyModeEnabled(isSafetyModeEnabled: boolean): void;
    isMVFFeatureOnFloor(feature: Feature<MVFGeometry, {
        id: string;
    }>, floor: Floor): boolean;
    getMVFConnectionByCoordinate(coordinate: Coordinate): Feature<Point, SpaceProperties> | undefined;
    getShareableUrl(overrides?: {
        state?: E_APP_STATE;
        selectedPlaces?: Place[] | undefined;
        departures?: Place[] | undefined;
    }): string;
    /**
     * Get all the places whose relevant coordinates (usually the center) are within the area.
     */
    getPlacesWithinArea(area: Area): Set<Place>;
    cleanup(): void;
}
export default RootStore;
